@@ -3,19 +3,17 @@
  *
  * This software is published under the terms of the Apache Software
  * License version 1.1, a copy of which has been included with this
- * distribution in the LICENSE.APL file.  */
+ * distribution in the LICENSE.txt file.  */
 
 package org.apache.log4j.net;
 
 import org.apache.log4j.AppenderSkeleton;
-import org.apache.log4j.Layout;
-import org.apache.log4j.Priority;
+import org.apache.log4j.Level;
 import org.apache.log4j.helpers.CyclicBuffer;
 import org.apache.log4j.helpers.OptionConverter;
 import org.apache.log4j.helpers.LogLog;
 import org.apache.log4j.spi.LoggingEvent;
 import org.apache.log4j.spi.ErrorCode;
-import org.apache.log4j.spi.ErrorHandler;
 import org.apache.log4j.spi.TriggeringEventEvaluator;
 import java.util.Properties;
 import java.util.Date;
@@ -30,7 +28,6 @@ import javax.mail.internet.MimeMultipart;
 import javax.mail.internet.MimeBodyPart;
 import javax.mail.internet.InternetAddress;
 import javax.mail.internet.AddressException;
-import javax.mail.internet.MimeUtility;
 
 /**
    Send an e-mail when a specific logging event occurs, typically on
@@ -42,7 +39,7 @@ import javax.mail.internet.MimeUtility;
    <code>BufferSize</code> logging events in its cyclic buffer. This
    keeps memory requirements at a reasonable level while still
    delivering useful application context.
-   
+
    @author Ceki G&uuml;lc&uuml;
    @since 1.0 */
 public class SMTPAppender extends AppenderSkeleton {
@@ -56,94 +53,6 @@ public class SMTPAppender extends AppenderSkeleton {
   protected CyclicBuffer cb = new CyclicBuffer(bufferSize);
   protected Message msg;
 
-
-
- /**
-     A string constant used in naming the <em>To</em> field of
-     outgoing e-mail output file. Current value of this string
-     constant is <b>To</b>.
-
-     <p>Note that all option keys are case sensitive.
-     
-     @deprecated Options are now handled using the JavaBeans paradigm. 
-     This constant will be removed in the <em>near</em> term.
-  */
-  public static final String TO_OPTION = "To";
-
- /**
-     A string constant used in naming the <em>From</em> field of
-     outgoing e-mail output file. Current value of this string
-     constant is <b>From</b>.
-
-     <p>Note that all option keys are case sensitive.
-
-     @deprecated Options are now handled using the JavaBeans paradigm. 
-     This constant will be removed in the <em>near</em> term.     
-  */
-  public static final String FROM_OPTION = "From";
-
- /**
-     A string constant used in naming the <em>Subject</em> field of
-     outgoing e-mail output file. Current value of this string
-     constant is <b>Subject</b>.
-
-     <p>Note that all option keys are case sensitive.
-     
-     @deprecated Options are now handled using the JavaBeans paradigm. 
-     This constant will be removed in the <em>near</em> term.
-  */
-  public static final String SUBJECT_OPTION = "Subject";
-
-
- /**
-     A string constant used in naming the SMTP host that will be
-     contacted to send the e-mail. Current value of this string
-     constant is <b>SMTPHost</b>.
-
-     <p>Note that all option keys are case sensitive.
-     
-     @deprecated Options are now handled using the JavaBeans paradigm. 
-     This constant will be removed in the <em>near</em> term.
-  */
-  public static final String SMTP_HOST_OPTION = "SMTPHost";
-
- /**
-     A string constant used in naming the cyclic buffer size option.
-     Current value of this string constant is <b>BufferSize</b>.
-
-     <p>Note that all option keys are case sensitive.
-     
-     @deprecated Options are now handled using the JavaBeans paradigm. 
-     This constant will be removed in the <em>near</em> term.
-  */
-  public static final String BUFFER_SIZE_OPTION = "BufferSize";
-
-
- /**
-     A string constant used in naming the class of the
-     TriggeringEventEvaluator that this SMTPApepdner wll use. Current
-     value of this string constant is <b>EvaluatorClass</b>.
-
-     <p>Note that all option keys are case sensitive.
-     
-     @deprecated Options are now handled using the JavaBeans paradigm. 
-     This constant will be removed in the <em>near</em> term.
-  */
-  public static final String EVALUATOR_CLASS_OPTION = "EvaluatorClass";
-
-
-  /**
-     A string constant used in naming the option for setting the the
-     location information flag.  Current value of this string
-     constant is <b>LocationInfo</b>.  
-
-     <p>Note that all option keys are case sensitive.
-
-     @deprecated Options are now handled using the JavaBeans paradigm. 
-     This constant will be removed in the <em>near</em> term.
-  */
-  public static final String LOCATION_INFO_OPTION = "LocationInfo";
-  
   protected TriggeringEventEvaluator evaluator;
 
 
@@ -151,52 +60,36 @@ public class SMTPAppender extends AppenderSkeleton {
   /**
      The default constructor will instantiate the appender with a
      {@link TriggeringEventEvaluator} that will trigger on events with
-     priority ERROR or higher.*/
+     level ERROR or higher.*/
   public
   SMTPAppender() {
     this(new DefaultEvaluator());
   }
 
-  
+
   /**
      Use <code>evaluator</code> passed as parameter as the {@link
      TriggeringEventEvaluator} for this SMTPAppender.  */
-  public 
+  public
   SMTPAppender(TriggeringEventEvaluator evaluator) {
     this.evaluator = evaluator;
   }
 
- /**
-     Retuns the option names for this component in addition in
-     addition to the options of its super class {@link
-     AppenderSkeleton}.
-     
-     @deprecated We now use JavaBeans introspection to configure
-     components. Options strings are no longer needed.
-  */
-  public
-  String[] getOptionStrings() {
-    return OptionConverter.concatanateArrays(super.getOptionStrings(),
-          new String[] {TO_OPTION, FROM_OPTION, SUBJECT_OPTION, 
-			  SMTP_HOST_OPTION, BUFFER_SIZE_OPTION,  
-			  EVALUATOR_CLASS_OPTION, LOCATION_INFO_OPTION });
-  }
-  
 
   /**
      Activate the specified options, such as the smtp host, the
      recipient, from, etc. */
   public
   void activateOptions() {
-    Properties props = System.getProperties();
+    Properties props = new Properties (System.getProperties());
     if (smtpHost != null)
       props.put("mail.smtp.host", smtpHost);
 
-    
-    Session session = Session.getDefaultInstance(props, null);
+
+    Session session = Session.getInstance(props, null);
     //session.setDebug(true);
     msg = new MimeMessage(session);
-     
+
      try {
        if (from != null)
 	 msg.setFrom(getAddress(from));
@@ -210,7 +103,7 @@ public class SMTPAppender extends AppenderSkeleton {
        LogLog.error("Could not activate SMTPAppender options.", e );
      }
   }
-  
+
   /**
      Perform SMTPAppender specific appending actions, mainly adding
      the event to a cyclic buffer and checking if the event triggers
@@ -225,9 +118,9 @@ public class SMTPAppender extends AppenderSkeleton {
     event.getThreadName();
     event.getNDC();
     if(locationInfo) {
-      event.getLocationInformation();	
+      event.getLocationInformation();
     }
-    cb.add(event);    
+    cb.add(event);
     if(evaluator.isTriggeringEvent(event)) {
       sendBuffer();
     }
@@ -235,7 +128,7 @@ public class SMTPAppender extends AppenderSkeleton {
 
  /**
      This method determines if there is a sense in attempting to append.
-     
+
      <p>It checks whether there is a set output target and also if
      there is a set layout. If these checks fail, then the boolean
      value <code>false</code> is returned. */
@@ -252,7 +145,7 @@ public class SMTPAppender extends AppenderSkeleton {
       return false;
     }
 
-    
+
     if(this.layout == null) {
       errorHandler.error("No layout set for appender named ["+name+"].");
       return false;
@@ -297,8 +190,8 @@ public class SMTPAppender extends AppenderSkeleton {
 
 
   /**
-     The <code>SMTPAppender</code> requires a {@link Layout layout}.  
-  */
+     The <code>SMTPAppender</code> requires a {@link
+     org.apache.log4j.Layout layout}.  */
   public
   boolean requiresLayout() {
     return true;
@@ -312,14 +205,14 @@ public class SMTPAppender extends AppenderSkeleton {
 
     // Note: this code already owns the monitor for this
     // appender. This frees us from needing to synchronize on 'cb'.
-    try {      
+    try {
       MimeBodyPart part = new MimeBodyPart();
 
       StringBuffer sbuf = new StringBuffer();
       String t = layout.getHeader();
       if(t != null)
 	sbuf.append(t);
-      int len =  cb.length(); 
+      int len =  cb.length();
       for(int i = 0; i < len; i++) {
 	//sbuf.append(MimeUtility.encodeText(layout.format(cb.get())));
 	LoggingEvent event = cb.get();
@@ -336,19 +229,19 @@ public class SMTPAppender extends AppenderSkeleton {
       t = layout.getFooter();
       if(t != null)
 	sbuf.append(t);
-      part.setContent(sbuf.toString(), layout.getContentType());      
+      part.setContent(sbuf.toString(), layout.getContentType());
 
       Multipart mp = new MimeMultipart();
       mp.addBodyPart(part);
       msg.setContent(mp);
 
       msg.setSentDate(new Date());
-      Transport.send(msg);      
+      Transport.send(msg);
     } catch(Exception e) {
       LogLog.error("Error occured while sending e-mail notification.", e);
     }
   }
-  
+
 
 
   /**
@@ -358,7 +251,7 @@ public class SMTPAppender extends AppenderSkeleton {
   String getEvaluatorClass() {
     return evaluator == null ? null : evaluator.getClass().getName();
   }
-  
+
   /**
      Returns value of the <b>From</b> option.
    */
@@ -375,36 +268,6 @@ public class SMTPAppender extends AppenderSkeleton {
     return subject;
   }
 
-
-/**
-   @deprecated Use the setter method for the option directly, instead
-   of the generic <code>setOption</code> method.  */
-  public
-  void setOption(String option, String value) {
-    if(value == null) return;
-    super.setOption(option, value);    
-
-    if(option.equals(TO_OPTION)) 
-      to = value;
-    else if (option.equals(FROM_OPTION))
-      from = value;
-    else if (option.equals(SMTP_HOST_OPTION)) 
-      smtpHost = value;
-    else if (option.equals(SUBJECT_OPTION)) 
-      subject = value;
-    else if (option.equals(EVALUATOR_CLASS_OPTION)) {      
-      evaluator = (TriggeringEventEvaluator) 
-                OptionConverter.instantiateByClassName(value, 
-                                           TriggeringEventEvaluator.class,
-                                                       evaluator);    
-    } else if (option.equals(BUFFER_SIZE_OPTION)) {
-      bufferSize = OptionConverter.toInt(value, bufferSize);    
-      cb.resize(bufferSize);
-    } else if (option.equals(LOCATION_INFO_OPTION))
-      locationInfo = OptionConverter.toBoolean(value, locationInfo);
-  }
-
-
   /**
      The <b>From</b> option takes a string value which should be a
      e-mail address of the sender.
@@ -413,7 +276,7 @@ public class SMTPAppender extends AppenderSkeleton {
   void setFrom(String from) {
     this.from = from;
   }
-  
+
   /**
      The <b>Subject</b> option takes a string value which should be a
      the subject of the e-mail message.
@@ -422,7 +285,7 @@ public class SMTPAppender extends AppenderSkeleton {
   void setSubject(String subject) {
     this.subject = subject;
   }
-  
+
 
   /**
      The <b>BufferSize</b> option takes a positive integer
@@ -436,7 +299,7 @@ public class SMTPAppender extends AppenderSkeleton {
     this.bufferSize = bufferSize;
     cb.resize(bufferSize);
   }
-  
+
   /**
      The <b>SMTPHost</b> option takes a string value which should be a
      the host name of the SMTP server that will send the e-mail message.
@@ -445,7 +308,7 @@ public class SMTPAppender extends AppenderSkeleton {
   void setSMTPHost(String smtpHost) {
     this.smtpHost = smtpHost;
   }
-  
+
   /**
      Returns value of the <b>SMTPHost</b> option.
    */
@@ -463,7 +326,7 @@ public class SMTPAppender extends AppenderSkeleton {
     this.to = to;
   }
 
-  
+
 
   /**
      Returns value of the <b>BufferSize</b> option.
@@ -472,7 +335,7 @@ public class SMTPAppender extends AppenderSkeleton {
   int getBufferSize() {
     return bufferSize;
   }
-  
+
   /**
      The <b>EvaluatorClass</b> option takes a string value
      representing the name of the class implementing the {@link
@@ -482,13 +345,13 @@ public class SMTPAppender extends AppenderSkeleton {
    */
   public
   void setEvaluatorClass(String value) {
-      evaluator = (TriggeringEventEvaluator) 
-                OptionConverter.instantiateByClassName(value, 
+      evaluator = (TriggeringEventEvaluator)
+                OptionConverter.instantiateByClassName(value,
 					   TriggeringEventEvaluator.class,
-						       evaluator);    
+						       evaluator);
   }
-  
-  
+
+
   /**
      The <b>LocationInfo</b> option takes a boolean value. By
      default, it is set to false which means there will be no effort
@@ -496,7 +359,7 @@ public class SMTPAppender extends AppenderSkeleton {
      result, the layout that formats the events as they are sent out
      in an e-mail is likely to place the wrong location information
      (if present in the format).
-     
+
      <p>Location information extraction is comparatively very slow and
      should be avoided unless performance is not a concern.
    */
@@ -504,7 +367,7 @@ public class SMTPAppender extends AppenderSkeleton {
   void setLocationInfo(boolean locationInfo) {
     this.locationInfo = locationInfo;
   }
-  
+
   /**
      Returns value of the <b>LocationInfo</b> option.
    */
@@ -517,12 +380,12 @@ public class SMTPAppender extends AppenderSkeleton {
 class DefaultEvaluator implements TriggeringEventEvaluator {
   /**
      Is this <code>event</code> the e-mail triggering event?
-     
-     <p>This method returns <code>true</code>, if the event priority
-     has ERROR priority or higher. Otherwise it returns
+
+     <p>This method returns <code>true</code>, if the event level
+     has ERROR level or higher. Otherwise it returns
      <code>false</code>. */
-  public 
+  public
   boolean isTriggeringEvent(LoggingEvent event) {
-    return event.priority.isGreaterOrEqual(Priority.ERROR); 
+    return event.level.isGreaterOrEqual(Level.ERROR);
   }
 }
